(shell-command "echo foo" t)
(save-buffer)
(save-buffers-kill-emacs)
